@@ -12,4 +12,20 @@
 # from Novigi_Operators.novigi_json_to_csv import NovigiJsonToCSVExportOperator
 # from Novigi_Operators.novigi_xls_to_csv_operator import NovigiXlsToCSVOperator
 
-from prasadi.operators.sample_operator import SampleOperator
+#from prasadi.operators.sample_operator import SampleOperator
+
+from airflow.plugins_manager import AirflowPlugin
+
+#from mailgun_plugin.hooks import MailgunHook
+#from mailgun_plugin.operators import EmailValidationOperator
+
+from prasadi.operators import SampleOperator
+
+
+
+class Prasadi(AirflowPlugin):
+    name = 'prasadi'
+    
+    operators = [
+        SampleOperator
+    ]
